"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _draftJs = require("draft-js");

var _highlightToCompositeDecorator = _interopRequireDefault(require("./highlightToCompositeDecorator.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var HighlightWithinTextareaFunc = (0, _react.forwardRef)(function (props, ref) {
  var placeholder = props.placeholder,
      highlight = props.highlight,
      onChange = props.onChange,
      value = props.value;

  var _useState = (0, _react.useState)({
    prev: {
      value: null,
      editorState: null
    },
    next: {
      value: null,
      editorState: null
    }
  }),
      onChangeState = _useState[0],
      setOnChangeState = _useState[1];

  var editorState;

  if (value === onChangeState.next.value) {
    editorState = onChangeState.next.editorState;
  } else if (value === onChangeState.prev.value) {
    editorState = onChangeState.prev.editorState;
  } else {
    var contentState = _draftJs.ContentState.createFromText(value);

    editorState = _draftJs.EditorState.createWithContent(contentState);
  }

  var decorator = (0, _react.useMemo)(function () {
    return (0, _highlightToCompositeDecorator["default"])(highlight);
  }, [highlight]);

  if (decorator !== editorState.decorator) {
    editorState = _draftJs.EditorState.set(editorState, {
      decorator: decorator
    });
  }

  var onDraftChange = function onDraftChange(editorState) {
    var value = editorState.getCurrentContent().getPlainText();
    setOnChangeState({
      prev: onChangeState.next,
      next: {
        value: value,
        editorState: editorState
      }
    });
    onChange(value);
  };

  return /*#__PURE__*/_react["default"].createElement(_draftJs.Editor, {
    editorState: editorState,
    onChange: onDraftChange,
    placeholder: placeholder,
    ref: ref
  });
});
/*
 * For some reason, exporting a FunctionComponent
 * doesn't work when importing in codepen.io, so wrap
 * it in a class component.
 */

var HighlightWithinTextarea = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(HighlightWithinTextarea, _React$Component);

  function HighlightWithinTextarea(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;
    _this.state = {
      date: new Date()
    };
    return _this;
  }

  var _proto = HighlightWithinTextarea.prototype;

  _proto.render = function render() {
    return /*#__PURE__*/_react["default"].createElement(HighlightWithinTextareaFunc, this.props);
  };

  return HighlightWithinTextarea;
}(_react["default"].Component);

HighlightWithinTextarea.propTypes = process.env.NODE_ENV !== "production" ? {
  onChange: _propTypes["default"].func,
  value: _propTypes["default"].string.isRequired,
  highlight: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].array, _propTypes["default"].instanceOf(RegExp), _propTypes["default"].object, _propTypes["default"].func]),
  placeholder: _propTypes["default"].string
} : {};
HighlightWithinTextarea.defaultProps = {
  highlight: null,
  placeholder: "Enter some text..."
};
var _default = HighlightWithinTextarea;
exports["default"] = _default;
module.exports = exports.default;